=====
Usage
=====

Nono, le petit robot d'assistance a l entraide humaine.

NonoSolaris permet de compiler les annuaires des cellules Solaris qui le souhaitent.
Un référent collecte les formulaires remplis par les membres (disponible
`ici <https://raw.githubusercontent.com/numengo/python-nonosolaris/main/nonosolaris/templates/formulaire_annuaire_v1.0.pdf>`__)
, les copie dans un repertoire, et NonoSolaris génèrera un annuaire mis en forme, daté et indexé

::
    $ nonosolaris address-book write-edition

Ce référent peut ensuite imprimer 3 exemplaires papiers identiques et les remettre aux 3 référents.

Il est possible d actionner NonoSolaris sur une clé usb stockant les fiches des membres et
déconnectée du réseau, pour le temps de l opération.


